--[[
Script to fix the path for the DLC's

Author:		Ifko[nator], Bone2510
Date:		23.06.2023
Version:	1.1

History:	V1.0 @21.06.2023 - initial implementation in FS 22
			--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
			V1.1 @23.06.2023 - implementation of <overwrittenPaths> (modDesc) readout for overwriting sound file paths
]]

GetFilenameFixForDLC = {};
GetFilenameFixForDLC.currentModDirectory = g_currentModDirectory;
GetFilenameFixForDLC.OVERWRITTENPATHS = {};

local overwrittenPathNumber = 0;
local modDesc = loadXMLFile("modDesc", GetFilenameFixForDLC.currentModDirectory .. "modDesc.xml");
local overwrittenPathKey = "modDesc.overwrittenPaths.overwrittenPath(" .. tostring(overwrittenPathNumber) .. ")";

while hasXMLProperty(modDesc, overwrittenPathKey) do
	local overwrittenPath = {};
	overwrittenPathKey = "modDesc.overwrittenPaths.overwrittenPath(" .. tostring(overwrittenPathNumber) .. ")";

	local originalPath = getXMLString(modDesc, overwrittenPathKey .. "#originalPath");
	local newPath = getXMLString(modDesc, overwrittenPathKey .. "#newPath");

	if originalPath ~= nil and newPath ~= nil then
		overwrittenPath.originalPath = originalPath;
		overwrittenPath.newPath = newPath;

		table.insert(GetFilenameFixForDLC.OVERWRITTENPATHS, overwrittenPath);
		print("Added overwrittenPath: " .. originalPath .. " -> " .. newPath);
        overwrittenPathNumber = overwrittenPathNumber + 1;
	end;
end;


function GetFilenameFixForDLC.getFilename(filename, superFunc, baseDir)
	if filename == nil then
		printCallstack();

		return nil;
	end;

	if type(filename) == "boolean" then
		printCallstack();
	end;

	-- Search for Path entry
	for i, overwrittenPath in ipairs(GetFilenameFixForDLC.OVERWRITTENPATHS) do
		if filename == overwrittenPath.originalPath then
			filename = overwrittenPath.newPath;
			break;
		end;
	end;

	if filename:find("$pdlcdir") then
		local path = getUserProfileAppPath() .. "pdlc" .. filename:sub(9);

		if not fileExists(path) then
			path = getUserProfileAppPath() .. "pdlc" .. filename:sub(9, filename:len() - 4) .. ".dds";
		end;

		if not fileExists(path) then
			path = getAppBasePath() .. "pdlc" .. filename:sub(9);

			if not fileExists(path) then
				path = getAppBasePath() .. "pdlc" .. filename:sub(9, filename:len() - 4) .. ".dds";
			end;
		end;

		return path, false;
	elseif filename:sub(1, 1) == "$" then
		return filename:sub(2), false;
	elseif baseDir == nil or baseDir == "" then
		return filename, false;
	elseif filename == "" then
		return filename, true;
	end;

	return baseDir .. filename, true;
end;

Utils.getFilename = Utils.overwrittenFunction(Utils.getFilename, GetFilenameFixForDLC.getFilename);